@@ -54,6 +54,10 @@ typedef unsigned int size_t;
 typedef int ssize_t;
 #endif
 
+#ifndef HAVE_PTRDIFF_T
+typedef long ptrdiff_t;
+#endif
+
 #ifdef HAVE_STRINGS_H
 # include <strings.h>
 #endif
@@ -62,10 +66,6 @@ typedef int ssize_t;
 # include <sys/types.h>
 #endif
 
-#ifdef HAVE_LIBGDBM
-# include <gdbm.h>
-#endif
-
 #ifdef HAVE_SYS_STAT_H
 # include <sys/stat.h>
 #endif
