@@ -40,46 +40,46 @@
  */
 
 #define MASTER_SECRET "master secret"
-static int generate_normal_master( GNUTLS_STATE state);
+static int generate_normal_master( gnutls_session session);
 
-int _gnutls_generate_master( GNUTLS_STATE state) {
-	if (state->gnutls_internals.resumed==RESUME_FALSE)
-		return generate_normal_master(state);
+int _gnutls_generate_master( gnutls_session session) {
+	if (session->internals.resumed==RESUME_FALSE)
+		return generate_normal_master(session);
 	return 0;
 }
 
 /* here we generate the TLS Master secret.
  */
-#define PREMASTER state->gnutls_key->key
-static int generate_normal_master( GNUTLS_STATE state) {
+#define PREMASTER session->gnutls_key->key
+static int generate_normal_master( gnutls_session session) {
 int ret = 0;
 char random[2*TLS_RANDOM_SIZE];
 
-	memcpy(random, state->security_parameters.client_random, TLS_RANDOM_SIZE);
-	memcpy(&random[TLS_RANDOM_SIZE], state->security_parameters.server_random, TLS_RANDOM_SIZE);
+	memcpy(random, session->security_parameters.client_random, TLS_RANDOM_SIZE);
+	memcpy(&random[TLS_RANDOM_SIZE], session->security_parameters.server_random, TLS_RANDOM_SIZE);
 
 	_gnutls_hard_log( "INT: PREMASTER SECRET[%d]: %s\n", PREMASTER.size, _gnutls_bin2hex(PREMASTER.data, PREMASTER.size));
-	_gnutls_hard_log( "INT: CLIENT RANDOM[%d]: %s\n", 32, _gnutls_bin2hex(state->security_parameters.client_random,32));
-	_gnutls_hard_log( "INT: SERVER RANDOM[%d]: %s\n", 32, _gnutls_bin2hex(state->security_parameters.server_random,32));
+	_gnutls_hard_log( "INT: CLIENT RANDOM[%d]: %s\n", 32, _gnutls_bin2hex(session->security_parameters.client_random,32));
+	_gnutls_hard_log( "INT: SERVER RANDOM[%d]: %s\n", 32, _gnutls_bin2hex(session->security_parameters.server_random,32));
 
-	if ( gnutls_protocol_get_version( state) == GNUTLS_SSL3) {
+	if ( gnutls_protocol_get_version( session) == GNUTLS_SSL3) {
 		ret =
 		    _gnutls_ssl3_generate_random( PREMASTER.data, PREMASTER.size,
 			       random, 2*TLS_RANDOM_SIZE, TLS_MASTER_SIZE,
-			       state->security_parameters.master_secret);
+			       session->security_parameters.master_secret);
 
 	} else {
 		ret =
 		    _gnutls_PRF( PREMASTER.data, PREMASTER.size,
 			       MASTER_SECRET, strlen(MASTER_SECRET),
 			       random, 2*TLS_RANDOM_SIZE, TLS_MASTER_SIZE, 
-			       state->security_parameters.master_secret); 
+			       session->security_parameters.master_secret); 
 	}
 	gnutls_sfree_datum(&PREMASTER);
 	
 	if (ret<0) return ret;
 	
-	_gnutls_hard_log( "INT: MASTER SECRET: %s\n", _gnutls_bin2hex(state->security_parameters.master_secret, TLS_MASTER_SIZE));
+	_gnutls_hard_log( "INT: MASTER SECRET: %s\n", _gnutls_bin2hex(session->security_parameters.master_secret, TLS_MASTER_SIZE));
 
 	return ret;
 }
@@ -89,20 +89,20 @@ char random[2*TLS_RANDOM_SIZE];
  * server. It does nothing if this type of message is not required
  * by the selected ciphersuite. 
  */
-int _gnutls_send_server_kx_message( GNUTLS_STATE state, int again)
+int _gnutls_send_server_kx_message( gnutls_session session, int again)
 {
 	uint8 *data = NULL;
 	int data_size = 0;
 	int ret = 0;
 
-	if (state->gnutls_internals.auth_struct->gnutls_generate_server_kx==NULL) 
+	if (session->internals.auth_struct->gnutls_generate_server_kx==NULL) 
 		return 0;
 
 	data = NULL;
 	data_size = 0;
 
 	if (again == 0) {
-		data_size = state->gnutls_internals.auth_struct->gnutls_generate_server_kx( state, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_server_kx( session, &data);
 		
 		if (data_size == GNUTLS_E_INT_RET_0) {
 			gnutls_assert();
@@ -115,7 +115,7 @@ int _gnutls_send_server_kx_message( GNUTLS_STATE state, int again)
 		}
 	}
 	
-	ret = _gnutls_send_handshake( state, data, data_size, GNUTLS_SERVER_KEY_EXCHANGE);
+	ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_SERVER_KEY_EXCHANGE);
 	gnutls_free(data);
 
 	if (ret < 0) {
@@ -128,30 +128,30 @@ int _gnutls_send_server_kx_message( GNUTLS_STATE state, int again)
 /* This function sends a certificate request message to the
  * client.
  */
-int _gnutls_send_server_certificate_request( GNUTLS_STATE state, int again)
+int _gnutls_send_server_certificate_request( gnutls_session session, int again)
 {
 	uint8 *data = NULL;
 	int data_size = 0;
 	int ret = 0;
 
-	if (state->gnutls_internals.auth_struct->gnutls_generate_server_certificate_request==NULL) 
+	if (session->internals.auth_struct->gnutls_generate_server_certificate_request==NULL) 
 		return 0;
 
-	if (state->gnutls_internals.send_cert_req <= 0)
+	if (session->internals.send_cert_req <= 0)
 		return 0;
 		
 	data = NULL;
 	data_size = 0;
 
 	if (again == 0) {
-		data_size = state->gnutls_internals.auth_struct->gnutls_generate_server_certificate_request( state, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_server_certificate_request( session, &data);
 
 		if (data_size < 0) {
 			gnutls_assert();
 			return data_size;
 		}
 	}
-	ret = _gnutls_send_handshake( state, data, data_size, GNUTLS_CERTIFICATE_REQUEST);
+	ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_CERTIFICATE_REQUEST);
 	gnutls_free(data);
 
 	if (ret < 0) {
@@ -162,20 +162,20 @@ int _gnutls_send_server_certificate_request( GNUTLS_STATE state, int again)
 }
 
 /* Currently only used in SRP */
-int _gnutls_send_server_kx_message2( GNUTLS_STATE state, int again)
+int _gnutls_send_server_kx_message2( gnutls_session session, int again)
 {
 	uint8 *data = NULL;
 	int data_size = 0;
 	int ret = 0;
 
-	if (state->gnutls_internals.auth_struct->gnutls_generate_server_kx2 == NULL)
+	if (session->internals.auth_struct->gnutls_generate_server_kx2 == NULL)
 		return 0;
 
 	data = NULL;
 	data_size = 0;
 
 	if (again == 0) {
-		data_size = state->gnutls_internals.auth_struct->gnutls_generate_server_kx2( state, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_server_kx2( session, &data);
 
 		if (data_size<0) {
 			gnutls_assert();
@@ -183,7 +183,7 @@ int _gnutls_send_server_kx_message2( GNUTLS_STATE state, int again)
 		}
 	}
 
-	ret = _gnutls_send_handshake( state, data, data_size, GNUTLS_SERVER_KEY_EXCHANGE);
+	ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_SERVER_KEY_EXCHANGE);
 		
 	gnutls_free(data);
 	if (ret<0) {
@@ -197,13 +197,13 @@ int _gnutls_send_server_kx_message2( GNUTLS_STATE state, int again)
 /* This is the function for the client to send the key
  * exchange message 
  */
-int _gnutls_send_client_kx_message( GNUTLS_STATE state, int again)
+int _gnutls_send_client_kx_message( gnutls_session session, int again)
 {
 	uint8 *data;
 	int data_size;
 	int ret = 0;
 
-	if (state->gnutls_internals.auth_struct->gnutls_generate_client_kx==NULL) 
+	if (session->internals.auth_struct->gnutls_generate_client_kx==NULL) 
 		return 0;
 
 
@@ -211,13 +211,13 @@ int _gnutls_send_client_kx_message( GNUTLS_STATE state, int again)
 	data_size = 0;
 
 	if (again == 0) {
-		data_size = state->gnutls_internals.auth_struct->gnutls_generate_client_kx( state, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_client_kx( session, &data);
 		if (data_size < 0) {
 			gnutls_assert();
 			return data_size;
 		}
 	}
-    	ret = _gnutls_send_handshake( state, data, data_size, GNUTLS_CLIENT_KEY_EXCHANGE);
+    	ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_CLIENT_KEY_EXCHANGE);
 	gnutls_free(data);
 
 	if (ret<0) {
@@ -230,13 +230,13 @@ int _gnutls_send_client_kx_message( GNUTLS_STATE state, int again)
 
 /* Only used in SRP currently
  */
-int _gnutls_send_client_kx_message0( GNUTLS_STATE state, int again)
+int _gnutls_send_client_kx_message0( gnutls_session session, int again)
 {
 	uint8 *data;
 	int data_size;
 	int ret = 0;
 
-	if ( state->gnutls_internals.auth_struct->gnutls_generate_client_kx0 == NULL)
+	if ( session->internals.auth_struct->gnutls_generate_client_kx0 == NULL)
 		return 0;
 
 
@@ -244,14 +244,14 @@ int _gnutls_send_client_kx_message0( GNUTLS_STATE state, int again)
 	data_size = 0;
 
 	if (again == 0) {
-		data_size = state->gnutls_internals.auth_struct->gnutls_generate_client_kx0( state, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_client_kx0( session, &data);
 
 		if (data_size < 0) {
 			gnutls_assert();
 			return data_size;
 		}
 	}
-	ret = _gnutls_send_handshake( state, data, data_size, GNUTLS_CLIENT_KEY_EXCHANGE);
+	ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_CLIENT_KEY_EXCHANGE);
 	gnutls_free(data);
 
 	return ret;
@@ -261,7 +261,7 @@ int _gnutls_send_client_kx_message0( GNUTLS_STATE state, int again)
 /* This is the function for the client to send the certificate
  * verify message
  */
-int _gnutls_send_client_certificate_verify( GNUTLS_STATE state, int again)
+int _gnutls_send_client_certificate_verify( gnutls_session session, int again)
 {
 	uint8 *data;
 	int ret = 0;
@@ -269,15 +269,15 @@ int _gnutls_send_client_certificate_verify( GNUTLS_STATE state, int again)
 
 	/* This is a packet that is only sent by the client
 	 */
-	if (state->security_parameters.entity==GNUTLS_SERVER) return 0;
+	if (session->security_parameters.entity==GNUTLS_SERVER) return 0;
 	
 	/* if certificate verify is not needed just exit 
 	 */
-	if (state->gnutls_key->certificate_requested==0) {
+	if (session->gnutls_key->certificate_requested==0) {
 		return 0;
 	}
 
-	if (state->gnutls_internals.auth_struct->gnutls_generate_client_cert_vrfy==NULL) {
+	if (session->internals.auth_struct->gnutls_generate_client_cert_vrfy==NULL) {
 		gnutls_assert();
 		return 0; /* this algorithm does not support cli_cert_vrfy 
 		           */
@@ -287,7 +287,7 @@ int _gnutls_send_client_certificate_verify( GNUTLS_STATE state, int again)
 	data_size = 0;
 
 	if (again == 0) {
-		data_size = state->gnutls_internals.auth_struct->gnutls_generate_client_cert_vrfy( state, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_client_cert_vrfy( session, &data);
 		if (data_size < 0) {
 			gnutls_assert();
 			return data_size;
@@ -297,7 +297,7 @@ int _gnutls_send_client_certificate_verify( GNUTLS_STATE state, int again)
 
 	}
 	ret =
-	    _gnutls_send_handshake( state, data,
+	    _gnutls_send_handshake( session, data,
 				   data_size,
 				   GNUTLS_CERTIFICATE_VERIFY);
 	gnutls_free(data);
@@ -306,24 +306,24 @@ int _gnutls_send_client_certificate_verify( GNUTLS_STATE state, int again)
 }
 
 
-int _gnutls_recv_server_kx_message( GNUTLS_STATE state)
+int _gnutls_recv_server_kx_message( gnutls_session session)
 {
 	uint8 *data = NULL;
 	int datasize;
 	int ret = 0;
 
-	if (state->gnutls_internals.auth_struct->gnutls_process_server_kx!=NULL) {
+	if (session->internals.auth_struct->gnutls_process_server_kx!=NULL) {
 
 		/* EXCEPTION FOR RSA_EXPORT cipher suite 
 		 */
-		if ( _gnutls_session_is_export( state) != 0 &&
-			_gnutls_peers_cert_less_512(state) != 0) {
+		if ( _gnutls_session_is_export( session) != 0 &&
+			_gnutls_peers_cert_less_512(session) != 0) {
 				gnutls_assert();
 				return 0;
 		}
 
 		ret =
-		    _gnutls_recv_handshake( state, &data,
+		    _gnutls_recv_handshake( session, &data,
 				   &datasize,
 				   GNUTLS_SERVER_KEY_EXCHANGE, MANDATORY_PACKET);
 		if (ret < 0) {
@@ -331,7 +331,7 @@ int _gnutls_recv_server_kx_message( GNUTLS_STATE state)
 			return ret;
 		}
 
-		ret = state->gnutls_internals.auth_struct->gnutls_process_server_kx( state, data, datasize);
+		ret = session->internals.auth_struct->gnutls_process_server_kx( session, data, datasize);
 		gnutls_free(data);
 
 		if (ret < 0) {
@@ -343,16 +343,16 @@ int _gnutls_recv_server_kx_message( GNUTLS_STATE state)
 	return ret;
 }
 
-int _gnutls_recv_server_certificate_request( GNUTLS_STATE state)
+int _gnutls_recv_server_certificate_request( gnutls_session session)
 {
 	uint8 *data;
 	int datasize;
 	int ret = 0;
 
-	if (state->gnutls_internals.auth_struct->gnutls_process_server_certificate_request!=NULL) {
+	if (session->internals.auth_struct->gnutls_process_server_certificate_request!=NULL) {
 
 		ret =
-		    _gnutls_recv_handshake( state, &data,
+		    _gnutls_recv_handshake( session, &data,
 				   &datasize,
 				   GNUTLS_CERTIFICATE_REQUEST, OPTIONAL_PACKET);
 		if (ret < 0)
@@ -361,7 +361,7 @@ int _gnutls_recv_server_certificate_request( GNUTLS_STATE state)
 		if (ret==0 && datasize == 0)
 			return 0; /* ignored */
 		
-		ret = state->gnutls_internals.auth_struct->gnutls_process_server_certificate_request( state, data, datasize);
+		ret = session->internals.auth_struct->gnutls_process_server_certificate_request( session, data, datasize);
 		gnutls_free(data);
 		if (ret < 0)
 			return ret;
@@ -370,24 +370,24 @@ int _gnutls_recv_server_certificate_request( GNUTLS_STATE state)
 	return ret;
 }
 
-int _gnutls_recv_server_kx_message2( GNUTLS_STATE state)
+int _gnutls_recv_server_kx_message2( gnutls_session session)
 {
 	uint8 *data;
 	int datasize;
 	int ret = 0;
 
 
-	if (state->gnutls_internals.auth_struct->gnutls_process_server_kx2 != NULL) {
+	if (session->internals.auth_struct->gnutls_process_server_kx2 != NULL) {
 
 		ret =
-		    _gnutls_recv_handshake( state, &data,
+		    _gnutls_recv_handshake( session, &data,
 				   &datasize,
 				   GNUTLS_SERVER_KEY_EXCHANGE, MANDATORY_PACKET);
 		if (ret < 0)
 			return ret;
 
 
-		ret = state->gnutls_internals.auth_struct->gnutls_process_server_kx2( state, data, datasize);
+		ret = session->internals.auth_struct->gnutls_process_server_kx2( session, data, datasize);
 		gnutls_free(data);
 		if (ret < 0)
 			return ret;
@@ -396,7 +396,7 @@ int _gnutls_recv_server_kx_message2( GNUTLS_STATE state)
 	return ret;
 }
 
-int _gnutls_recv_client_kx_message( GNUTLS_STATE state)
+int _gnutls_recv_client_kx_message( gnutls_session session)
 {
 	uint8 *data;
 	int datasize;
@@ -404,16 +404,16 @@ int _gnutls_recv_client_kx_message( GNUTLS_STATE state)
 
 
 	/* Do key exchange only if the algorithm permits it */
-	if (state->gnutls_internals.auth_struct->gnutls_process_client_kx != NULL) {
+	if (session->internals.auth_struct->gnutls_process_client_kx != NULL) {
 
 		ret =
-		    _gnutls_recv_handshake( state, &data,
+		    _gnutls_recv_handshake( session, &data,
 					   &datasize,
 					   GNUTLS_CLIENT_KEY_EXCHANGE, MANDATORY_PACKET);
 		if (ret < 0)
 			return ret;
 
-		ret = state->gnutls_internals.auth_struct->gnutls_process_client_kx( state, data, datasize);
+		ret = session->internals.auth_struct->gnutls_process_client_kx( session, data, datasize);
 		gnutls_free(data);
 		if (ret < 0)
 			return ret;
@@ -424,23 +424,23 @@ int _gnutls_recv_client_kx_message( GNUTLS_STATE state)
 }
 
 /* only used in SRP */
-int _gnutls_recv_client_kx_message0( GNUTLS_STATE state)
+int _gnutls_recv_client_kx_message0( gnutls_session session)
 {
 	uint8 *data;
 	int datasize;
 	int ret = 0;
 
 	/* Do key exchange only if the algorithm permits it */
-	if (state->gnutls_internals.auth_struct->gnutls_process_client_kx0 != NULL) {
+	if (session->internals.auth_struct->gnutls_process_client_kx0 != NULL) {
 
 		ret =
-		    _gnutls_recv_handshake( state, &data,
+		    _gnutls_recv_handshake( session, &data,
 					   &datasize,
 					   GNUTLS_CLIENT_KEY_EXCHANGE, MANDATORY_PACKET);
 		if (ret < 0)
 			return ret;
 
-		ret = state->gnutls_internals.auth_struct->gnutls_process_client_kx0( state, data, datasize);
+		ret = session->internals.auth_struct->gnutls_process_client_kx0( session, data, datasize);
 		gnutls_free(data);
 		if (ret < 0)
 			return ret;
@@ -451,31 +451,31 @@ int _gnutls_recv_client_kx_message0( GNUTLS_STATE state)
 
 /* This is called when we want send our certificate
  */
-int _gnutls_send_client_certificate( GNUTLS_STATE state, int again)
+int _gnutls_send_client_certificate( gnutls_session session, int again)
 {
 	uint8 *data = NULL;
 	int data_size = 0;
 	int ret = 0;
 
 
-	if (state->gnutls_key->certificate_requested == 0)
+	if (session->gnutls_key->certificate_requested == 0)
 		return 0;
 
-	if (state->gnutls_internals.auth_struct->gnutls_generate_client_certificate==NULL) 
+	if (session->internals.auth_struct->gnutls_generate_client_certificate==NULL) 
 		return 0;
 
 	data = NULL;
 	data_size = 0;
 
 	if (again == 0) {
-		data_size = state->gnutls_internals.auth_struct->gnutls_generate_client_certificate( state, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_client_certificate( session, &data);
 
 		if (data_size < 0) {
 			gnutls_assert();
 			return data_size;
 		}
 	}
-	ret = _gnutls_send_handshake( state, data, data_size, GNUTLS_CERTIFICATE_PKT);
+	ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_CERTIFICATE_PKT);
 	gnutls_free(data);
 	
 	if (ret<0) {
@@ -489,28 +489,28 @@ int _gnutls_send_client_certificate( GNUTLS_STATE state, int again)
 
 /* This is called when we want send our certificate
  */
-int _gnutls_send_server_certificate( GNUTLS_STATE state, int again)
+int _gnutls_send_server_certificate( gnutls_session session, int again)
 {
 	uint8 *data = NULL;
 	int data_size = 0;
 	int ret = 0;
 
 
-	if (state->gnutls_internals.auth_struct->gnutls_generate_server_certificate==NULL) 
+	if (session->internals.auth_struct->gnutls_generate_server_certificate==NULL) 
 		return 0;
 
 	data = NULL;
 	data_size = 0;
 
 	if (again == 0) {
-		data_size = state->gnutls_internals.auth_struct->gnutls_generate_server_certificate( state, &data);
+		data_size = session->internals.auth_struct->gnutls_generate_server_certificate( session, &data);
 
 		if (data_size < 0) {
 			gnutls_assert();
 			return data_size;
 		}
 	}
-	ret = _gnutls_send_handshake( state, data, data_size, GNUTLS_CERTIFICATE_PKT);
+	ret = _gnutls_send_handshake( session, data, data_size, GNUTLS_CERTIFICATE_PKT);
 	gnutls_free(data);
 	
 	if (ret < 0) {
@@ -522,35 +522,35 @@ int _gnutls_send_server_certificate( GNUTLS_STATE state, int again)
 }
 
 
-int _gnutls_recv_client_certificate( GNUTLS_STATE state)
+int _gnutls_recv_client_certificate( gnutls_session session)
 {
 	int datasize;
 	opaque * data;
 	int ret = 0;
 	int optional;
 
-	if (state->gnutls_internals.auth_struct->gnutls_process_client_certificate!=NULL) {
+	if (session->internals.auth_struct->gnutls_process_client_certificate!=NULL) {
 
 		/* if we have not requested a certificate then just return
 		 */
-		if ( state->gnutls_internals.send_cert_req == 0) {
+		if ( session->internals.send_cert_req == 0) {
 			return 0;
 		}
 
-		if ( state->gnutls_internals.send_cert_req == GNUTLS_CERT_REQUIRE)
+		if ( session->internals.send_cert_req == GNUTLS_CERT_REQUIRE)
 			optional = MANDATORY_PACKET;
 		else 
 			optional = OPTIONAL_PACKET;
 
 		ret =
-		    _gnutls_recv_handshake( state, &data,
+		    _gnutls_recv_handshake( session, &data,
 					   &datasize,
 					   GNUTLS_CERTIFICATE_PKT, optional);
 		if (ret < 0) {
 			if (optional == OPTIONAL_PACKET &&
 			        ret==GNUTLS_E_WARNING_ALERT_RECEIVED && 
-			        gnutls_protocol_get_version(state) == GNUTLS_SSL3 &&
-				gnutls_alert_get(state)==GNUTLS_A_SSL3_NO_CERTIFICATE) {
+			        gnutls_protocol_get_version(session) == GNUTLS_SSL3 &&
+				gnutls_alert_get(session)==GNUTLS_A_SSL3_NO_CERTIFICATE) {
 
 				/* SSL3 does not send an empty certificate,
 				 * but this alert. So we just ignore it.
@@ -574,7 +574,7 @@ int _gnutls_recv_client_certificate( GNUTLS_STATE state)
 		}
 
 
-		ret = state->gnutls_internals.auth_struct->gnutls_process_client_certificate( state, data, datasize);
+		ret = session->internals.auth_struct->gnutls_process_client_certificate( session, data, datasize);
 		gnutls_free(data);
 		if (ret < 0 && ret != GNUTLS_E_NO_CERTIFICATE_FOUND) {
 			gnutls_assert();
@@ -586,23 +586,23 @@ int _gnutls_recv_client_certificate( GNUTLS_STATE state)
 		if (ret==GNUTLS_E_NO_CERTIFICATE_FOUND && optional == OPTIONAL_PACKET)
 			ret = 0;
 		else
-			state->gnutls_key->certificate_requested = 1;
+			session->gnutls_key->certificate_requested = 1;
 
 	}
 
 	return ret;
 }
 
-int _gnutls_recv_server_certificate( GNUTLS_STATE state)
+int _gnutls_recv_server_certificate( gnutls_session session)
 {
 	int datasize;
 	opaque * data;
 	int ret = 0;
 
-	if (state->gnutls_internals.auth_struct->gnutls_process_server_certificate!=NULL) {
+	if (session->internals.auth_struct->gnutls_process_server_certificate!=NULL) {
 
 		ret =
-		    _gnutls_recv_handshake( state, &data,
+		    _gnutls_recv_handshake( session, &data,
 					   &datasize,
 					   GNUTLS_CERTIFICATE_PKT, MANDATORY_PACKET);
 		if (ret < 0) {
@@ -610,7 +610,7 @@ int _gnutls_recv_server_certificate( GNUTLS_STATE state)
 			return ret;
 		}
 
-		ret = state->gnutls_internals.auth_struct->gnutls_process_server_certificate( state, data, datasize);
+		ret = session->internals.auth_struct->gnutls_process_server_certificate( session, data, datasize);
 		gnutls_free(data);
 		if (ret < 0) {
 			gnutls_assert();
@@ -625,34 +625,34 @@ int _gnutls_recv_server_certificate( GNUTLS_STATE state)
 /* Recv the client certificate verify. This packet may not
  * arrive if the peer did not send us a certificate.
  */
-int _gnutls_recv_client_certificate_verify_message( GNUTLS_STATE state)
+int _gnutls_recv_client_certificate_verify_message( gnutls_session session)
 {
 	uint8 *data;
 	int datasize;
 	int ret = 0;
 
 
-	if (state->gnutls_internals.auth_struct->gnutls_process_client_cert_vrfy != NULL) {
+	if (session->internals.auth_struct->gnutls_process_client_cert_vrfy != NULL) {
 
-		if ( state->gnutls_internals.send_cert_req == 0 ||
-			state->gnutls_key->certificate_requested == 0) {
+		if ( session->internals.send_cert_req == 0 ||
+			session->gnutls_key->certificate_requested == 0) {
 			return 0;
 		}
 
 		ret =
-		    _gnutls_recv_handshake( state, &data,
+		    _gnutls_recv_handshake( session, &data,
 					   &datasize,
 					   GNUTLS_CERTIFICATE_VERIFY, OPTIONAL_PACKET);
 		if (ret < 0)
 			return ret;
 
-		if (ret==0 && datasize == 0 && state->gnutls_internals.send_cert_req == GNUTLS_CERT_REQUIRE) {
+		if (ret==0 && datasize == 0 && session->internals.send_cert_req == GNUTLS_CERT_REQUIRE) {
 			/* certificate was required */
 			gnutls_assert();
 			return GNUTLS_E_NO_CERTIFICATE_FOUND;
 		} 
 		
-		ret = state->gnutls_internals.auth_struct->gnutls_process_client_cert_vrfy( state, data, datasize);
+		ret = session->internals.auth_struct->gnutls_process_client_cert_vrfy( session, data, datasize);
 		gnutls_free(data);
 		if (ret < 0)
 			return ret;
