@@ -1,20 +1,15 @@
 #ifndef GNUTLS_PK_H
 # define GNUTLS_PK_H
 
-typedef enum PKAlgorithm { GNUTLS_PK_RSA = 1, GNUTLS_PK_DSA,	/* sign only */
-	GNUTLS_PK_DH, GNUTLS_PK_UNKNOWN 
-} PKAlgorithm;
-
-int _gnutls_pk_encrypt(int algo, MPI * resarr, MPI data, MPI * pkey);
 int _gnutls_pkcs1_rsa_encrypt(gnutls_datum * ciphertext, gnutls_datum plaintext,
-		      MPI * params, int btype);
+		      MPI * params, int params_len, int btype);
 int _gnutls_dsa_sign(gnutls_datum * signature, const gnutls_datum *plaintext,
-		      MPI *params);
+		      MPI *params, int params_len);
 int _gnutls_pkcs1_rsa_decrypt(gnutls_datum * plaintext, gnutls_datum ciphertext,
-		      MPI * params, int btype);
+		      MPI * params, int params_len, int btype);
 int _gnutls_rsa_verify( const gnutls_datum* vdata, const gnutls_datum *ciphertext, 
-	MPI* params, int btype);
+	MPI* params, int params_len, int btype);
 int _gnutls_dsa_verify( const gnutls_datum* vdata, const gnutls_datum *sig_value, 
-	MPI * params);
+	MPI * params, int params_len);
 
 #endif /* GNUTLS_PK_H */
