@@ -19,6 +19,9 @@
  *
  */
 
+/* This file contains functions needed to read DSA or RSA private keys
+ * from files, or memory.
+ */
 
 #include <gnutls_int.h>
 #include <gnutls_errors.h>
@@ -30,8 +33,6 @@
 #include <gnutls_mpi.h>
 #include <gnutls_global.h>
 
-void _gcry_mpi_invm( MPI x, MPI a, MPI n );
-
 /* Converts an RSA PKCS#1 key to
  * an internal structure (gnutls_private_key)
  */
