@@ -1,6 +1,6 @@
 #include <libtasn1.h>
 
-int _gnutls_x509_cert_verify_peers(GNUTLS_STATE state);
+int _gnutls_x509_cert_verify_peers(gnutls_session session);
 
 typedef enum ConvFlags { 
 	CERT_NO_COPY=2, 
@@ -10,12 +10,18 @@ typedef enum ConvFlags {
 
 int _gnutls_x509_cert2gnutls_cert(gnutls_cert * gCert, gnutls_datum derCert, ConvFlags flags);
 
+/* for int2str */
 #define MAX_INT_DIGITS 4
 void _gnutls_int2str(unsigned int k, char *data);
 
-#define PEM_CERT_SEP "-----BEGIN"
+#define PEM_CERT_SEP2 "-----BEGIN X509 CERTIFICATE"
+#define PEM_CERT_SEP "-----BEGIN CERTIFICATE"
+#define PEM_PKCS7_SEP "-----BEGIN PKCS7"
 
-int _gnutls_check_x509_key_usage( const gnutls_cert * cert, KXAlgorithm alg);
+#define PEM_KEY_RSA_SEP "-----BEGIN RSA"
+#define PEM_KEY_DSA_SEP "-----BEGIN DSA"
+
+int _gnutls_check_x509_key_usage( const gnutls_cert * cert, gnutls_kx_algorithm alg);
 time_t gnutls_x509_extract_certificate_activation_time( const gnutls_datum*);
 time_t gnutls_x509_extract_certificate_expiration_time( const gnutls_datum*);
 
