@@ -127,12 +127,31 @@ int gen_srp_server_hello(gnutls_session state, opaque * data, int data_size)
 	_gnutls_mpi_set(N, pwd_entry->n);
 	_gnutls_mpi_set(V, pwd_entry->v);
 
-	if (data_size < n_n + n_g + pwd_entry->salt_size + 6) {
+	if (data_size < n_n + n_g + pwd_entry->salt_size + 5) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
 	}
 
-	data_g = data; 
+	/* copy the salt 
+	 */
+	data_s = data;
+
+	n_s = pwd_entry->salt_size;
+	memcpy(&data_s[1], pwd_entry->salt, n_s);
+
+	data_s[0] = (uint8) n_s;
+
+	/* copy N (mod n) */
+	data_n = &data_s[1 + n_s];
+
+	if (_gnutls_mpi_print( &data_n[2], &n_n, N)!=0) {
+		gnutls_assert();
+		return GNUTLS_E_MPI_PRINT_FAILED;
+	}
+	
+	_gnutls_write_uint16( n_n, data_n);
+
+	data_g = &data_n[2 + n_n];
 
 	/* copy G (generator) to data */
 
@@ -143,24 +162,7 @@ int gen_srp_server_hello(gnutls_session state, opaque * data, int data_size)
 	
 	_gnutls_write_uint16( n_g, data_g);
 
-	/* copy N (mod n) */
-	data_n = &data_g[2 + n_g];
-
-	if (_gnutls_mpi_print( &data_n[2], &n_n, N)!=0) {
-		gnutls_assert();
-		return GNUTLS_E_MPI_PRINT_FAILED;
-	}
-	
-	_gnutls_write_uint16( n_n, data_n);
-
-	/* copy the salt */
-	data_s = &data_n[2 + n_n];
-	n_s = pwd_entry->salt_size;
-	memcpy(&data_s[2], pwd_entry->salt, n_s);
-
-	_gnutls_write_uint16( n_s, data_s);
-
-	ret = n_g + n_n + pwd_entry->salt_size + 6 + 1;
+	ret = n_g + n_n + pwd_entry->salt_size + 5;
 	_gnutls_srp_clear_pwd_entry( pwd_entry);
 
 	return ret;
@@ -235,7 +237,7 @@ int gen_srp_client_kx0(gnutls_session state, opaque ** data)
 	uint8 *data_a;
 	char *username;
 	char *password;
-	const GNUTLS_SRP_CLIENT_CREDENTIALS cred =
+	const gnutls_srp_client_credentials cred =
 	    _gnutls_get_cred(state->gnutls_key, GNUTLS_CRD_SRP, NULL);
 
 	if (cred == NULL) {
@@ -285,7 +287,8 @@ int gen_srp_client_kx0(gnutls_session state, opaque ** data)
 /* receive the first key exchange message ( g, n, s) */
 int proc_srp_server_hello(gnutls_session state, const opaque * data, int data_size)
 {
-	uint16 n_s, n_g, n_n;
+	uint8 n_s;
+	uint16 n_g, n_n;
 	size_t _n_s, _n_g, _n_n;
 	const uint8 *data_n;
 	const uint8 *data_g;
@@ -294,7 +297,7 @@ int proc_srp_server_hello(gnutls_session state, const opaque * data, int data_si
 	opaque hd[SRP_MAX_HASH_SIZE];
 	char *username;
 	char *password;
-	const GNUTLS_SRP_CLIENT_CREDENTIALS cred =
+	const gnutls_srp_client_credentials cred =
 	    _gnutls_get_cred(state->gnutls_key, GNUTLS_CRD_SRP, NULL);
 
 	if (cred == NULL) {
@@ -305,24 +308,20 @@ int proc_srp_server_hello(gnutls_session state, const opaque * data, int data_si
 	username = cred->username;
 	password = cred->password;
 
-	if (username == NULL || password == NULL)
+	if (username == NULL || password == NULL) {
+		gnutls_assert();
 		return GNUTLS_E_INSUFICIENT_CRED;
+	}
 
-/* read the algorithm used to generate V */
-	
 	i = 0;
 
-	DECR_LEN( data_size, 2);
-	n_g = _gnutls_read_uint16( &data[i]);
-	i += 2;
+	DECR_LEN( data_size, 1);
+	n_s = data[i];
+	i += 1;
 
-	DECR_LEN( data_size, n_g);
-	data_g = &data[i];
-	i += n_g;
-	if (i > data_size) {
-		gnutls_assert();
-		return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
-	}
+	DECR_LEN( data_size, n_s);
+	data_s = &data[i];
+	i += n_s;
 
 	DECR_LEN( data_size, 2);
 	n_n = _gnutls_read_uint16( &data[i]);
@@ -333,12 +332,12 @@ int proc_srp_server_hello(gnutls_session state, const opaque * data, int data_si
 	i += n_n;
 	
 	DECR_LEN( data_size, 2);
-	n_s = _gnutls_read_uint16( &data[i]);
+	n_g = _gnutls_read_uint16( &data[i]);
 	i += 2;
 
-	DECR_LEN( data_size, n_s);
-	data_s = &data[i];
-	i += n_s;
+	DECR_LEN( data_size, n_g);
+	data_g = &data[i];
+	i += n_g;
 
 	_n_s = n_s;
 	_n_g = n_g;
