@@ -22,41 +22,21 @@
 
 #ifdef ENABLE_SRP
 
-#include "crypt_bcrypt.h"
 #include "crypt_srpsha1.h"
 #include "gnutls_random.h"
 
-char * gnutls_crypt(const char* username, const char *passwd, crypt_algo algo, int salt, GNUTLS_MPI g, GNUTLS_MPI n) {
+char * _gnutls_srp_crypt(const char* username, const char *passwd, int salt, GNUTLS_MPI g, GNUTLS_MPI n) {
 	
-	switch(algo) {
-	case BLOWFISH_CRYPT: /* bcrypt */
-		/* salt in bcrypt is actually the cost */
-		return crypt_bcrypt_wrapper(username, passwd, salt, g, n);
-	case SRPSHA1_CRYPT: /* bcrypt */
-		/* salt in bcrypt is the salt size */
-		return crypt_srpsha1_wrapper(username, passwd, salt, g, n);
-	}
-	return NULL;
+	return _gnutls_crypt_srpsha1_wrapper(username, passwd, salt, g, n);
 }
 
-int gnutls_crypt_vrfy(const char* username, const char *passwd, char* salt, GNUTLS_MPI g, GNUTLS_MPI n) {
+int _gnutls_srp_crypt_vrfy(const char* username, const char *passwd, char* salt, GNUTLS_MPI g, GNUTLS_MPI n) {
 	char* cr;
 
-	switch(salt[0]) {
-	case '$':
-		switch(salt[1]) {
-		case '2':
-			cr = crypt_bcrypt(username, passwd, salt, g, n);
-			if (cr==NULL) return 1;
-			if (strncmp(cr, salt, strlen(cr))==0) return 0;
-			break;
-		}
-	default:
-		cr = crypt_srpsha1(username, passwd, salt, g, n);
-		if (cr==NULL) return 1;
-		if (strncmp(cr, salt, strlen(cr))==0) return 0;
-		break;
-	}
+	cr = _gnutls_crypt_srpsha1(username, passwd, salt, g, n);
+	if (cr==NULL) return 1;
+	if (strncmp(cr, salt, strlen(cr))==0) return 0;
+
 	return 1;
 }
 
