@@ -1,10 +1,13 @@
 #include <stdio.h>
+#include <stdlib.h>
 #include <gnutls/gnutls.h>
 #include <gnutls/extra.h>
 #include <time.h>
 
 void print_cert_info(gnutls_session session);
 
+#undef XML
+
 #define PRINTX(x,y) if (y[0]!=0) printf(" #   %s %s\n", x, y)
 #define PRINT_DN(X) PRINTX( "CN:", X.common_name); \
 	PRINTX( "OU:", X.organizational_unit_name); \
@@ -49,6 +52,19 @@ void print_x509_info(gnutls_session session)
 	if (cert_list_size <= 0)
 		return;
 
+#ifdef XML
+		{
+			gnutls_datum res;
+	
+			gnutls_x509_certificate_to_xml( &cert_list[0], &res, 0);
+			printf( res.data);
+			
+			free(res.data);
+	
+			return;
+	}
+#endif
+
 	printf(" - Certificate info:\n");
 
 	printf(" # Certificate is valid since: %s", my_ctime( &activet));
@@ -125,6 +141,19 @@ void print_openpgp_info(gnutls_session session)
 	if (cert_list_size > 0) {
 		int algo, bits;
 
+#ifdef XML
+		{
+			gnutls_datum res;
+	
+			gnutls_openpgp_key_to_xml( &cert_list[0], &res, 0);
+			printf( res.data);
+			
+			free(res.data);
+	
+			return;
+	}
+#endif
+
 		printf(" # Key was created at: %s", my_ctime( &activet));
 		printf(" # Key expires: ");
 		if (expiret != 0)
