@@ -5,6 +5,7 @@
 #define UNSURE -1
 
 int test_srp( GNUTLS_STATE state);
+int test_export( GNUTLS_STATE state);
 int test_hello_extension( GNUTLS_STATE state);
 int test_dhe( GNUTLS_STATE state);
 int test_ssl3( GNUTLS_STATE state);
@@ -22,6 +23,7 @@ int test_anonymous( GNUTLS_STATE state);
 int test_unknown_ciphersuites( GNUTLS_STATE state);
 int test_openpgp1( GNUTLS_STATE state);
 int test_bye( GNUTLS_STATE state);
+int test_certificate( GNUTLS_STATE state);
 int test_session_resume2( GNUTLS_STATE state);
 
 #define GERR(ret) fprintf(stderr, "*** Error: %s\n", gnutls_strerror(ret))
